
/* Chrysalide - Outil d'analyse de fichiers binaires
 * constants.c - équivalent Python partiel du fichier "plugins/dex/dex_def.h"
 *
 * Copyright (C) 2018 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "constants.h"


#include <plugins/pychrysalide/helpers.h>


#include "../dex_def.h"



/* Définit les constantes communes pour le format Dex. */
static bool define_python_dex_format_common_constants(PyTypeObject *);


/******************************************************************************
*                                                                             *
*  Paramètres  : obj_type = type dont le dictionnaire est à compléter.        *
*                                                                             *
*  Description : Définit les constantes communes pour le format Dex.          *
*                                                                             *
*  Retour      : true en cas de succès de l'opération, false sinon.           *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static bool define_python_dex_format_common_constants(PyTypeObject *obj_type)
{
    bool result;                            /* Bilan à retourner           */

    result = true;

    /* Définition des drapeaux d'accès */

    if (result) result = PyDict_AddIntMacro(obj_type, ACC_PUBLIC);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_PRIVATE);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_PROTECTED);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_STATIC);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_FINAL);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_SYNCHRONIZED);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_VOLATILE);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_BRIDGE);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_TRANSIENT);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_VARARGS);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_NATIVE);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_INTERFACE);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_ABSTRACT);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_STRICT);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_SYNTHETIC);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_ANNOTATION);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_ENUM);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_CONSTRUCTOR);
    if (result) result = PyDict_AddIntMacro(obj_type, ACC_DECLARED_SYNCHRONIZED);

    return result;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : obj_type = type dont le dictionnaire est à compléter.        *
*                                                                             *
*  Description : Définit les constantes pour le format Dex.                   *
*                                                                             *
*  Retour      : true en cas de succès de l'opération, false sinon.           *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool define_python_dex_format_constants(PyTypeObject *obj_type)
{
    bool result;                            /* Bilan à retourner           */

    result = define_python_dex_format_common_constants(obj_type);

    return result;

}
